#
# spec file for package python-moto
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%if 0%{?suse_version} >= 1500
%define skip_python2 1
%endif
Name:           python-moto
Version:        1.3.16
Release:        bp153.1.1
Summary:        Library to mock out the boto library
License:        Apache-2.0
URL:            https://github.com/spulec/moto
Source:         https://files.pythonhosted.org/packages/source/m/moto/moto-%{version}.tar.gz
# PATCH-FIX-UPSTREAM moto-pr3273-escape-sequences.patch gh#spulec/moto#3273 fix escape sequences so that subsequent patches apply without rebase
Patch0:         https://github.com/spulec/moto/pull/3273.patch#/moto-pr3273-escape-sequences.patch
# PATCH-FIX-UPSTREAM moto-pr3308-fix-test_s3.patch gh#spulec/moto#3308 -- fix test failure
Patch1:         https://github.com/spulec/moto/pull/3308.patch#/moto-pr3308-fix-test_s3.patch
# PATCH-FEATURE-UPSTREAM remove_nose.patch gh#spulec/moto#3361 mcepl@suse.com
# Port test suite from nose to pytest
Patch2:         remove_nose.patch
# PATCH-FEATURE-UPSTREAM denose_exceptions.patch gh#spulec/moto#3361 mcepl@suse.com
# Continuation of the previous patch
Patch3:         denose_exceptions.patch
# PATCH-FIX-UPSTREAM moto-pr3412-fix-cfn-lint.patch -- gh#spulec/moto#3412 Fix failures with newer cfn-lint
Patch4:         https://github.com/spulec/moto/pull/3412.patch#/moto-pr3412-fix-cfn-lint.patch
# PATCH-FIX-UPSTREAM moto-pr3444-fix-docker.patch -- gh#spulec/moto#3444 Fix docker failure in test
Patch5:         https://github.com/spulec/moto/pull/3444.patch#/moto-pr3444-fix-docker.patch
# PATCH-FIX-UPSTREAM moto-pr3575-managedblockchain-botocore-api.patch -- gh#spulec/moto#3575 Support change botocore api
Patch6:         https://github.com/spulec/moto/pull/3575.patch#/moto-pr3575-managedblockchain-botocore-api.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Jinja2 >= 2.10.1
Requires:       python-PyYAML >= 5.1
Requires:       python-Werkzeug
Requires:       python-aws-xray-sdk >= 0.93
Requires:       python-boto >= 2.36.0
Requires:       python-boto3 >= 1.9.201
Requires:       python-botocore >= 1.12.201
Requires:       python-cfn-lint >= 0.4.0
Requires:       python-cryptography >= 2.3.0
Requires:       python-docker >= 2.5.1
Requires:       python-idna >= 2.5
Requires:       python-jsondiff >= 1.1.2
Requires:       python-mock
Requires:       python-python-dateutil >= 2.1
Requires:       python-python-jose
Requires:       python-pytz
Requires:       python-requests >= 2.5
Requires:       python-responses >= 0.9.0
Requires:       python-six > 1.9
Requires:       python-sshpubkeys >= 3.1.0
Requires:       python-xmltodict
%if %{python_version_nodots} < 37
%if 0%{?suse_version} >= 1550
# gh#spulec/moto#3576
Requires:       python-importlib-resources
%else
Requires:       python-importlib_resources
%endif
%endif
Requires(post): update-alternatives
Requires(preun): update-alternatives
Recommends:     python-Flask
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Flask}
BuildRequires:  %{python_module Jinja2 >= 2.10.1}
BuildRequires:  %{python_module PyYAML >= 5.1}
BuildRequires:  %{python_module Werkzeug}
BuildRequires:  %{python_module aws-xray-sdk >= 0.93}
BuildRequires:  %{python_module boto >= 2.36.0}
BuildRequires:  %{python_module boto3 >= 1.9.201}
BuildRequires:  %{python_module botocore >= 1.12.201}
BuildRequires:  %{python_module cfn-lint >= 0.4.0}
BuildRequires:  %{python_module cryptography >= 2.3.0}
BuildRequires:  %{python_module docker >= 2.5.1}
BuildRequires:  %{python_module freezegun}
BuildRequires:  %{python_module idna >= 2.5}
%if 0%{?suse_version} >= 1550
# For Python versions without importlib.resources, but it does not hurt to install the package for all flavors.
BuildRequires:  %{python_module importlib-resources}
%else
BuildRequires:  %{python_module importlib_resources}
%endif
BuildRequires:  %{python_module jsondiff >= 1.1.2}
BuildRequires:  %{python_module jsonpickle}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module parameterized}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil >= 2.1}
BuildRequires:  %{python_module python-jose}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module requests >= 2.5}
BuildRequires:  %{python_module responses >= 0.9.0}
BuildRequires:  %{python_module six > 1.9}
BuildRequires:  %{python_module sshpubkeys >= 3.1.0}
BuildRequires:  %{python_module sure}
BuildRequires:  %{python_module xmltodict}
%if %{with python2}
BuildRequires:  python-backports.tempfile
%endif
# /SECTION
%ifpython2
Requires:       python-backports.tempfile
%endif
%python_subpackages

%description
A library that allows your python tests to mock out the boto
library.

%prep
%setup -q -n moto-%{version}
%autopatch -p1

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%python_clone -a %{buildroot}%{_bindir}/moto_server

%check
# skipped tests require network connection
export BOTO_CONFIG=/dev/null
%pytest -k 'not network' tests/

%post
%python_install_alternative moto_server

%preun
%python_uninstall_alternative moto_server

%files %{python_files}
%doc AUTHORS.md README.md
%license LICENSE
%python_alternative %{_bindir}/moto_server
%{python_sitelib}/*

%changelog
* Sun Mar  7 2021 Yuchen Lin <mlin+factory@suse.de>
- Use python-importlib_resources to instead of python-importlib-resources
  for non-Factory version
* Sat Jan  2 2021 Benjamin Greiner <code@bnavigator.de>
- Fix test suite failures because of newer packages
  * Add moto-pr3273-escape-sequences.patch gh#spulec/moto#3273
  * Add moto-pr3308-fix-test_s3.patch gh#spulec/moto#3308
  * Add moto-pr3412-fix-cfn-lint.patch gh#spulec/moto#3412
  * Add moto-pr3444-fix-docker.patch gh#spulec/moto#3444
  * Add moto-pr3575-managedblockchain-botocore-api.patch
    gh#spulec/moto#3575
  * Refresh denose_exceptions.patch
- Fix Leap and python36 flavor failure, because importlib_resources
  is required for older Pythons -- gh#spulec/moto#3576
* Thu Nov 26 2020 Robert Schweikert <rjschwei@suse.com>
- Only build Python3 flavors for distributions 15 and greater
* Tue Oct  6 2020 Matej Cepl <mcepl@suse.com>
- Add remove_nose.patch and denose_exceptions.patch
  patches for porting the test suite to pytest
  (https://github.com/spulec/moto/pull/3361).
* Fri Sep 25 2020 Hans-Peter Jansen <hpj@urpla.net>
- Update to 1.3.16:
- Update to 1.3.15:
  * Many various updates see CHANGELOG.md
- Drop merged patches
  * dynabodbstreams.patch
  * iot-1.patch
  * iot-2.patch
  * iot-3.patch
  * lambdas.patch
- Remove no longer needed patch
  * unpin-reqs.patch
- Exclude 3 failing tests (docker related)
* Mon May  4 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Tue Feb 18 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.3.14:
  * Support for Python 3.8
  * Many various updates see CHANGELOG.md
- Drop merged patch botocore.patch
- Add patches to build with new botocore:
  * dynabodbstreams.patch
  * iot-1.patch
  * iot-2.patch
  * iot-3.patch
  * lambdas.patch
* Wed Oct 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to fix working with newer botocore from upstream
  git:
  * botocore.patch
* Wed Oct 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Enable testsuite
* Wed Oct 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.3.13:
  * Various fixes and updates to match up features in boto/botocore
* Thu May 16 2019 Scott Wulf <swulf@suse.com>
- Update to version 1.3.8:
  * No changelog details provided (24 days since revision change)
- Added unpin-reqs.patch
  * Unpin jsondiff
* Sat Dec 15 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Thu May 18 2017 toddrme2178@gmail.com
- Initial version (1.3.7)
